@@ -25,6 +25,8 @@ use Math::BigFloat 1.60;
 use overload '""' => \&bstr;
 use POSIX qw(locale_h);
 
+use constant _LEGACY_MATH_BIGINT => (Math::BigInt->VERSION <= '1.999717');
+
 @ISA = qw(Exporter Math::BigFloat);
 
 # Items to export into callers namespace by default. Note: do not export
@@ -39,7 +41,7 @@ use POSIX qw(locale_h);
   Money
 );
 
-$VERSION = 0.47;
+$VERSION = 0.48;
 
 $PACKAGE = __PACKAGE__;
 
@@ -89,6 +91,9 @@ sub new                  #05/10/99 3:13:PM
 
     my $value = shift || 0;
 
+    if (eval("'1.01' ne 1.01")) { # this might be a comma locale
+	$value =~ tr/,/./;
+    }
     $value =~ tr/-()0-9.//cd;    #strip any formatting characters
     $value = "-$value" if $value =~ s/(^\()|(\)$)//g;    # handle parens
 
@@ -314,7 +319,8 @@ sub as_int {
 # we override the default here because we only want to compare the precision of
 # the currency we're dealing with, not the precision of the underlying object
 sub bcmp {
-    my $class = shift;
+    # must use package for Math::BigInt >= 1.999717. See RT #115247
+    my $class = _LEGACY_MATH_BIGINT ? shift : __PACKAGE__;
 
     # make sure we're dealing with two Math::Currency objects
     my ( $x, $y ) =
